@@ -1,6 +1,6 @@
 import websockets
 
-from src.ArcProbeInterface.baseapi import API
+from .baseapi import API
 
 
 class AsyncAPI(API):
