@@ -1,6 +1,6 @@
 from websocket import create_connection
 
-from src.ArcProbeInterface.baseapi import API
+from .baseapi import API
 
 
 class SyncAPI(API):
